==> ViennaCL-1.7.0.tar.gz: ViennaCL-1.7.0/doc/html/search/classes_13.js <==
var searchData=
[
  ['tag_5feigen',['tag_eigen',['../structviennacl_1_1tag__eigen.html',1,'viennacl']]],
  ['tag_5fmtl4',['tag_mtl4',['../structviennacl_1_1tag__mtl4.html',1,'viennacl']]],
  ['tag_5fnone',['tag_none',['../structviennacl_1_1tag__none.html',1,'viennacl']]],
  ['tag_5fof',['tag_of',['../structviennacl_1_1traits_1_1tag__of.html',1,'viennacl::traits']]],
  ['tag_5fstl',['tag_stl',['../structviennacl_1_1tag__stl.html',1,'viennacl']]],
  ['tag_5fublas',['tag_ublas',['../structviennacl_1_1tag__ublas.html',1,'viennacl']]],
  ['tag_5fviennacl',['tag_viennacl',['../structviennacl_1_1tag__viennacl.html',1,'viennacl']]],
  ['template_5fbase',['template_base',['../classviennacl_1_1device__specific_1_1template__base.html',1,'viennacl::device_specific']]],
  ['template_5fbase_5fimpl',['template_base_impl',['../classviennacl_1_1device__specific_1_1template__base__impl.html',1,'viennacl::device_specific']]],
  ['template_5fbase_5fimpl_3c_20matrix_5faxpy_5ftemplate_2c_20matrix_5faxpy_5fparameters_5ftype_20_3e',['template_base_impl&lt; matrix_axpy_template, matrix_axpy_parameters_type &gt;',['../classviennacl_1_1device__specific_1_1template__base__impl.html',1,'viennacl::device_specific']]],
  ['template_5fbase_5fimpl_3c_20matrix_5fproduct_5ftemplate_2c_20matrix_5fproduct_5fparameters_20_3e',['template_base_impl&lt; matrix_product_template, matrix_product_parameters &gt;',['../classviennacl_1_1device__specific_1_1template__base__impl.html',1,'viennacl::device_specific']]],
  ['template_5fbase_5fimpl_3c_20reduction_5ftemplate_2c_20reduction_5fparameters_20_3e',['template_base_impl&lt; reduction_template, reduction_parameters &gt;',['../classviennacl_1_1device__specific_1_1template__base__impl.html',1,'viennacl::device_specific']]],
  ['template_5fbase_5fimpl_3c_20row_5fwise_5freduction_5ftemplate_2c_20row_5fwise_5freduction_5fparameters_20_3e',['template_base_impl&lt; row_wise_reduction_template, row_wise_reduction_parameters &gt;',['../classviennacl_1_1device__specific_1_1template__base__impl.html',1,'viennacl::device_specific']]],
  ['template_5fbase_5fimpl_3c_20vector_5faxpy_5ftemplate_2c_20vector_5faxpy_5fparameters_20_3e',['template_base_impl&lt; vector_axpy_template, vector_axpy_parameters &gt;',['../classviennacl_1_1device__specific_1_1template__base__impl.html',1,'viennacl::device_specific']]],
  ['testdata',['testData',['../structtest_data.html',1,'']]],
  ['timer',['timer',['../classviennacl_1_1tools_1_1timer.html',1,'viennacl::tools']]],
  ['toeplitz_5fmatrix',['toeplitz_matrix',['../classviennacl_1_1toeplitz__matrix.html',1,'viennacl']]],
  ['traversal_5ffunctor',['traversal_functor',['../classviennacl_1_1device__specific_1_1tree__parsing_1_1traversal__functor.html',1,'viennacl::device_specific::tree_parsing']]],
  ['type',['type',['../structviennacl_1_1device__specific_1_1builtin__database_1_1database__type_1_1type.html',1,'viennacl::device_specific::builtin_database::database_type']]],
  ['type_5fto_5fstring',['type_to_string',['../structviennacl_1_1ocl_1_1type__to__string.html',1,'viennacl::ocl']]],
  ['type_5fto_5fstring',['type_to_string',['../structviennacl_1_1device__specific_1_1utils_1_1type__to__string.html',1,'viennacl::device_specific::utils']]],
  ['type_5fto_5fstring_3c_20char_20_3e',['type_to_string&lt; char &gt;',['../structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01char_01_4.html',1,'viennacl::device_specific::utils']]],
  ['type_5fto_5fstring_3c_20double_20_3e',['type_to_string&lt; double &gt;',['../structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01double_01_4.html',1,'viennacl::device_specific::utils']]],
  ['type_5fto_5fstring_3c_20float_20_3e',['type_to_string&lt; float &gt;',['../structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01float_01_4.html',1,'viennacl::device_specific::utils']]],
  ['type_5fto_5fstring_3c_20int_20_3e',['type_to_string&lt; int &gt;',['../structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01int_01_4.html',1,'viennacl::device_specific::utils']]],
  ['type_5fto_5fstring_3c_20long_20_3e',['type_to_string&lt; long &gt;',['../structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01long_01_4.html',1,'viennacl::device_specific::utils']]],
  ['type_5fto_5fstring_3c_20short_20_3e',['type_to_string&lt; short &gt;',['../structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01short_01_4.html',1,'viennacl::device_specific::utils']]],
  ['type_5fto_5fstring_3c_20unsigned_20char_20_3e',['type_to_string&lt; unsigned char &gt;',['../structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01unsigned_01char_01_4.html',1,'viennacl::device_specific::utils']]],
  ['type_5fto_5fstring_3c_20unsigned_20int_20_3e',['type_to_string&lt; unsigned int &gt;',['../structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01unsigned_01int_01_4.html',1,'viennacl::device_specific::utils']]],
  ['type_5fto_5fstring_3c_20unsigned_20long_20_3e',['type_to_string&lt; unsigned long &gt;',['../structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01unsigned_01long_01_4.html',1,'viennacl::device_specific::utils']]],
  ['type_5fto_5fstring_3c_20unsigned_20short_20_3e',['type_to_string&lt; unsigned short &gt;',['../structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01unsigned_01short_01_4.html',1,'viennacl::device_specific::utils']]],
  ['type_5fto_5ftype2',['type_to_type2',['../structviennacl_1_1linalg_1_1cuda_1_1detail_1_1type__to__type2.html',1,'viennacl::linalg::cuda::detail']]],
  ['type_5fto_5ftype2_3c_20double_20_3e',['type_to_type2&lt; double &gt;',['../structviennacl_1_1linalg_1_1cuda_1_1detail_1_1type__to__type2_3_01double_01_4.html',1,'viennacl::linalg::cuda::detail']]],
  ['type_5fto_5ftype2_3c_20float_20_3e',['type_to_type2&lt; float &gt;',['../structviennacl_1_1linalg_1_1cuda_1_1detail_1_1type__to__type2_3_01float_01_4.html',1,'viennacl::linalg::cuda::detail']]],
  ['typesafe_5fhost_5farray',['typesafe_host_array',['../classviennacl_1_1backend_1_1typesafe__host__array.html',1,'viennacl::backend']]],
  ['typesafe_5fhost_5farray_3c_20t_2c_20true_20_3e',['typesafe_host_array&lt; T, true &gt;',['../classviennacl_1_1backend_1_1typesafe__host__array_3_01_t_00_01true_01_4.html',1,'viennacl::backend']]]
];

==> ViennaCL-1.7.1.tar.gz: ViennaCL-1.7.1/doc/html/search/classes_13.js <==
var searchData=
[
  ['tag_5feigen',['tag_eigen',['../structviennacl_1_1tag__eigen.html',1,'viennacl']]],
  ['tag_5fmtl4',['tag_mtl4',['../structviennacl_1_1tag__mtl4.html',1,'viennacl']]],
  ['tag_5fnone',['tag_none',['../structviennacl_1_1tag__none.html',1,'viennacl']]],
  ['tag_5fof',['tag_of',['../structviennacl_1_1traits_1_1tag__of.html',1,'viennacl::traits']]],
  ['tag_5fstl',['tag_stl',['../structviennacl_1_1tag__stl.html',1,'viennacl']]],
  ['tag_5fublas',['tag_ublas',['../structviennacl_1_1tag__ublas.html',1,'viennacl']]],
  ['tag_5fviennacl',['tag_viennacl',['../structviennacl_1_1tag__viennacl.html',1,'viennacl']]],
  ['template_5fbase',['template_base',['../classviennacl_1_1device__specific_1_1template__base.html',1,'viennacl::device_specific']]],
  ['template_5fbase_5fimpl',['template_base_impl',['../classviennacl_1_1device__specific_1_1template__base__impl.html',1,'viennacl::device_specific']]],
  ['template_5fbase_5fimpl_3c_20matrix_5fproduct_5ftemplate_2c_20matrix_5fproduct_5fparameters_20_3e',['template_base_impl&lt; matrix_product_template, matrix_product_parameters &gt;',['../classviennacl_1_1device__specific_1_1template__base__impl.html',1,'viennacl::device_specific']]],
  ['testdata',['testData',['../structtest_data.html',1,'']]],
  ['timer',['timer',['../classviennacl_1_1tools_1_1timer.html',1,'viennacl::tools']]],
  ['toeplitz_5fmatrix',['toeplitz_matrix',['../classviennacl_1_1toeplitz__matrix.html',1,'viennacl']]],
  ['toeplitz_5fmatrix_3c_20numerict_2c_20alignmentv_20_3e',['toeplitz_matrix&lt; NumericT, AlignmentV &gt;',['../classviennacl_1_1toeplitz__matrix.html',1,'viennacl']]],
  ['traversal_5ffunctor',['traversal_functor',['../classviennacl_1_1device__specific_1_1tree__parsing_1_1traversal__functor.html',1,'viennacl::device_specific::tree_parsing']]],
  ['type',['type',['../structviennacl_1_1device__specific_1_1builtin__database_1_1database__type_1_1type.html',1,'viennacl::device_specific::builtin_database::database_type']]],
  ['type_5fto_5fstring',['type_to_string',['../structviennacl_1_1ocl_1_1type__to__string.html',1,'viennacl::ocl']]],
  ['type_5fto_5fstring',['type_to_string',['../structviennacl_1_1device__specific_1_1utils_1_1type__to__string.html',1,'viennacl::device_specific::utils']]],
  ['type_5fto_5fstring_3c_20char_20_3e',['type_to_string&lt; char &gt;',['../structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01char_01_4.html',1,'viennacl::device_specific::utils']]],
  ['type_5fto_5fstring_3c_20double_20_3e',['type_to_string&lt; double &gt;',['../structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01double_01_4.html',1,'viennacl::device_specific::utils']]],
  ['type_5fto_5fstring_3c_20float_20_3e',['type_to_string&lt; float &gt;',['../structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01float_01_4.html',1,'viennacl::device_specific::utils']]],
  ['type_5fto_5fstring_3c_20int_20_3e',['type_to_string&lt; int &gt;',['../structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01int_01_4.html',1,'viennacl::device_specific::utils']]],
  ['type_5fto_5fstring_3c_20long_20_3e',['type_to_string&lt; long &gt;',['../structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01long_01_4.html',1,'viennacl::device_specific::utils']]],
  ['type_5fto_5fstring_3c_20short_20_3e',['type_to_string&lt; short &gt;',['../structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01short_01_4.html',1,'viennacl::device_specific::utils']]],
  ['type_5fto_5fstring_3c_20unsigned_20char_20_3e',['type_to_string&lt; unsigned char &gt;',['../structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01unsigned_01char_01_4.html',1,'viennacl::device_specific::utils']]],
  ['type_5fto_5fstring_3c_20unsigned_20int_20_3e',['type_to_string&lt; unsigned int &gt;',['../structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01unsigned_01int_01_4.html',1,'viennacl::device_specific::utils']]],
  ['type_5fto_5fstring_3c_20unsigned_20long_20_3e',['type_to_string&lt; unsigned long &gt;',['../structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01unsigned_01long_01_4.html',1,'viennacl::device_specific::utils']]],
  ['type_5fto_5fstring_3c_20unsigned_20short_20_3e',['type_to_string&lt; unsigned short &gt;',['../structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01unsigned_01short_01_4.html',1,'viennacl::device_specific::utils']]],
  ['type_5fto_5ftype2',['type_to_type2',['../structviennacl_1_1linalg_1_1cuda_1_1detail_1_1type__to__type2.html',1,'viennacl::linalg::cuda::detail']]],
  ['type_5fto_5ftype2_3c_20double_20_3e',['type_to_type2&lt; double &gt;',['../structviennacl_1_1linalg_1_1cuda_1_1detail_1_1type__to__type2_3_01double_01_4.html',1,'viennacl::linalg::cuda::detail']]],
  ['type_5fto_5ftype2_3c_20float_20_3e',['type_to_type2&lt; float &gt;',['../structviennacl_1_1linalg_1_1cuda_1_1detail_1_1type__to__type2_3_01float_01_4.html',1,'viennacl::linalg::cuda::detail']]],
  ['typesafe_5fhost_5farray',['typesafe_host_array',['../classviennacl_1_1backend_1_1typesafe__host__array.html',1,'viennacl::backend']]],
  ['typesafe_5fhost_5farray_3c_20t_2c_20true_20_3e',['typesafe_host_array&lt; T, true &gt;',['../classviennacl_1_1backend_1_1typesafe__host__array_3_01_t_00_01true_01_4.html',1,'viennacl::backend']]]
];
